@@ -2,12 +2,18 @@ use serde::{Deserialize, Serialize};
 
 use crate::{convert, val_helpr::ValidationResult};
 
+pub mod radio;
+pub use radio::Radio;
+
 pub mod button;
 pub use button::Contents as Button;
 
 pub mod select;
 pub use select::Select;
 
+pub mod text_input;
+pub use text_input::TextInput;
+
 /// # Block Elements - interactive components
 /// [slack api docs 🔗](https://api.slack.com/reference/block-kit/block-elements)
 ///
@@ -31,8 +37,10 @@ pub enum BlockElement<'a> {
   Image,
   MultiSelect,
   OverflowMenu,
-  PlainInput,
-  RadioButtons,
+  RadioButtons(Radio<'a>),
+
+  #[serde(rename = "plain_text_input")]
+  TextInput(TextInput<'a>),
 
   #[serde(rename = "channels_select")]
   SelectPublicChannel(select::PublicChannel<'a>),
@@ -59,12 +67,15 @@ impl<'a> BlockElement<'a> {
       | Self::SelectUser(cts) => cts.validate(),
       | Self::SelectExternal(cts) => cts.validate(),
       | Self::SelectStatic(cts) => cts.validate(),
+      | Self::RadioButtons(cts) => cts.validate(),
       | rest => todo!("validation not implemented for {:?}", rest),
     }
   }
 }
 
 convert!(impl From<Button> for BlockElement<'static> => |b| BlockElement::Button(b));
+convert!(impl<'a> From<Radio<'a>> for BlockElement<'a> => |b| BlockElement::RadioButtons(b));
+convert!(impl<'a> From<TextInput<'a>> for BlockElement<'a> => |t| BlockElement::TextInput(t));
 
 convert!(impl<'a> From<Select<'a>> for BlockElement<'a>
     => |s| match s {
